==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/ct/tp/dst/grouping/NxmNxCtTpDst.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.ct.tp.dst.grouping;
import java.lang.Integer;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxCtTpDstGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-ct-tp-dst {
 *   leaf ct-tp-dst {
 *     type uint16;
 *   }
 *   leaf mask {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-ct-tp-dst-grouping/nxm-nx-ct-tp-dst</i>
 *
 * <p>To create instances of this class use {@link NxmNxCtTpDstBuilder}.
 * @see NxmNxCtTpDstBuilder
 *
 */
public interface NxmNxCtTpDst
    extends
    ChildOf<NxmNxCtTpDstGrouping>,
    Augmentable<NxmNxCtTpDst>
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-nx-ct-tp-dst");

    /**
     * @return <code>java.lang.Integer</code> <code>ctTpDst</code>, or <code>null</code> if not present
     */
    @Nullable Integer getCtTpDst();
    
    /**
     * @return <code>java.lang.Integer</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable Integer getMask();

}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/match/rev140714/nxm/nx/ct/tp/dst/grouping/NxmNxCtTpDst.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.nxm.nx.ct.tp.dst.grouping;
import java.lang.Integer;
import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.match.rev140714.NxmNxCtTpDstGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.ChildOf;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-match</b>
 * <pre>
 * container nxm-nx-ct-tp-dst {
 *   leaf ct-tp-dst {
 *     type uint16;
 *   }
 *   leaf mask {
 *     type uint16;
 *   }
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-match/nxm-nx-ct-tp-dst-grouping/nxm-nx-ct-tp-dst</i>
 *
 * <p>To create instances of this class use {@link NxmNxCtTpDstBuilder}.
 * @see NxmNxCtTpDstBuilder
 *
 */
public interface NxmNxCtTpDst
    extends
    ChildOf<NxmNxCtTpDstGrouping>,
    Augmentable<NxmNxCtTpDst>
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nxm-nx-ct-tp-dst");

    /**
     * @return <code>java.lang.Integer</code> <code>ctTpDst</code>, or <code>null</code> if not present
     */
    @Nullable Integer getCtTpDst();
    
    /**
     * @return <code>java.lang.Integer</code> <code>mask</code>, or <code>null</code> if not present
     */
    @Nullable Integer getMask();

}
